# gebaSpike
I am in the process of making this GUI that will hopefully improve my work flow for sorting in-vivo electrophysiology data 
within the Tint/Axona software climate.

## Requirements
1. Suggested Python 3.5 or later
2. PyQtGraph
3. Scipy
